@@ -1,7 +1,7 @@
 package App::ZodiacUtils;
 
-our $DATE = '2015-11-28'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -31,6 +31,12 @@ $SPEC{zodiac_of} = {
             result => 'gemini',
             test => 0, # at the time of this writing, Test::Rinci hasn't used Perinci::Sub::CoerceArgs
         },
+        {
+            summary => 'Multiple dates',
+            args => {dates=>['2015-12-17','2015-12-29']},
+            result => [["2015-12-17","sagittarius"], ["2015-12-29","capricornus"]],
+            test => 0,
+        }
     ],
 };
 sub zodiac_of {
@@ -73,6 +79,12 @@ $SPEC{chinese_zodiac_of} = {
             args => {dates=>['1980-02-17']},
             result => 'monkey (metal)',
         },
+        {
+            summary => 'Multiple dates',
+            args => {dates=>['2015-12-17','2016-12-17']},
+            result => [["2015-12-17","goat (wood)"], ["2016-12-17","monkey (fire)"]],
+            test => 0,
+        }
     ],
 
 };
@@ -111,7 +123,7 @@ App::ZodiacUtils - CLI utilities related to zodiac
 
 =head1 VERSION
 
-This document describes version 0.04 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2015-11-28.
+This document describes version 0.05 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2015-12-17.
 
 =head1 DESCRIPTION
 
@@ -135,6 +147,18 @@ Show Chinese zodiac for a date.
 Examples:
 
  chinese_zodiac_of( dates => ["1980-02-17"]); # -> "monkey (metal)"
+ chinese_zodiac_of( dates => ["2015-12-17", "2016-12-17"]);
+
+
+Result:
+
+ [
+   ["2015-12-17", "goat (wood)"],
+   ["2016-12-17", "monkey (fire)"],
+ ]
+Multiple dates.
+
+
 This function is not exportable.
 
 Arguments ('*' denotes required arguments):
@@ -166,6 +190,15 @@ Show zodiac for a date.
 Examples:
 
  zodiac_of( dates => ["2015-06-15"]); # -> "gemini"
+ zodiac_of( dates => ["2015-12-17", "2015-12-29"]);
+
+
+Result:
+
+ [["2015-12-17", "sagittarius"], ["2015-12-29", "capricornus"]]
+Multiple dates.
+
+
 This function is not exportable.
 
 Arguments ('*' denotes required arguments):
